# Homomorph
The HMM class is fully documented. However, the [tutorial]() is the recommended introduction to this package.

## Dependencies
Homomorph is designed to be lightweight and only requires NumPy for array calculations and SciPy for its implementation of random variables. The minimum versions were set to the most recent at the time of initial release (1.17 and 1.8, respectively), but no functionality specific to these releases is needed to my knowledge.

## Installation
To install Homomorph, run the following command:

```
pip install homomorph
```
